@@ -12,14 +12,18 @@ from ckanext.search_tweaks.spellcheck import (
 )
 
 
-@pytest.mark.ckan_config("ckan.plugins", "search_tweaks search_tweaks_spellcheck")
+@pytest.mark.ckan_config(
+    "ckan.plugins", "search_tweaks search_tweaks_spellcheck"
+)
 @pytest.mark.usefixtures("with_plugins")
 class TestSpellcheck:
     def test_plugin_loaded(self):
         assert p.plugin_loaded("search_tweaks_spellcheck")
 
 
-@pytest.mark.ckan_config("ckan.plugins", "search_tweaks search_tweaks_spellcheck")
+@pytest.mark.ckan_config(
+    "ckan.plugins", "search_tweaks search_tweaks_spellcheck"
+)
 @pytest.mark.usefixtures("with_plugins", "with_request_context")
 class TestDidYouMeanSnippet:
     def test_empty_without_data(self):
@@ -37,7 +41,9 @@ class TestDidYouMeanSnippet:
 
 
 @pytest.mark.ckanext_search_tweaks_modified_schema
-@pytest.mark.ckan_config("ckan.plugins", "search_tweaks search_tweaks_spellcheck")
+@pytest.mark.ckan_config(
+    "ckan.plugins", "search_tweaks search_tweaks_spellcheck"
+)
 @pytest.mark.usefixtures("with_plugins", "clean_db", "clean_index")
 class TestHelper:
     def test_recommendations(self):
